@@ -3,4 +3,4 @@ class OrderedRows(list):
     Maintains original header/field ordering.
     """
     def __init__(self, header):
-        self.header = header
+        self.header = [c.strip() for c in header] if (header is not None) else None
